Package 'daedalus.data'

Title: DAEDALUS Data
Description: Package to handel input data for the daedalus model.
Authors: Pablo Perez-Guzman [aut, cre] (ORCID: <https://orcid.org/0000-0002-5277-5196>), Pratik Gupte [aut] (ORCID: <https://orcid.org/0000-0001-5294-7819>), Patrick Doohan [aut] (ORCID: <https://orcid.org/0000-0001-8076-1106>), Robert Johnson [aut] (ORCID: <https://orcid.org/0000-0002-7365-0042>), Abdul Latif Jameel Institute for Disease and Emergency Analytics [fnd], Imperial College of Science, Technology and Medicine [cph, fnd]
Maintainer: Pablo Perez-Guzman <[email protected]>
License: MIT + file LICENSE
Version: 0.0.3
Built: 2026-05-08 07:04:14 UTC
Source: https://github.com/jameel-institute/daedalus.data

Help Index


Pandemic response strategy data for DAEDALUS

Description

Coefficients of openness of economic sectors under different pandemic response strategies. There are four strategies (including no response, identified as "none").

Usage

closure_strategy_data

closure_strategy_names

Format

closure_data

A list with 4 elements, each corresponding to a pandemic response strategy, each a vector N_ECONOMIC_SECTORS (45) giving the coefficients of sector openness.

none

All economic sectors are fully open and there is no pandemic response.

elimination

Openness coefficients for an elimination strategy.

economic_closures

Openness coefficients for a strategy of mostly economic closures.

school_closures

Openness coefficients for a strategy of mostly school closures.

An object of class character of length 4.

Multiple sources; to be updated shortly. See processing details in 'data-raw/closure_data.R


Country demographic data for DAEDALUS

Description

Country-wise data on demography, social contacts, workforce participation in economic sectors, and gross value added (GVA) per economic sector. Demography and social contacts are presented in four bins: ⁠[0, 4]⁠, ⁠[5, 19]⁠, ⁠[20, 64]⁠, and ⁠[65, ]⁠ (combining all individuals aged 65 and higher). Workforce participation is presented as counts which are assumed to be a subset of the ⁠[20, 64]⁠ age-bin. GVA data is presented in terms of million dollars per day.

Note that some zero values in worker participation data may reflect missing data for a particular sector.

Usage

country_data

Format

country_data

A list with 197 elements, each corresponding to a recognised country or territory.

demography

A four value named vector for the number of individuals in each demographic group.

contact_matrix

A 16-element square matrix giving the mean number of social contacts between individuals of the four age groups.

workers

A 45-element vector giving the number of individuals in each economic sector included in the model.

gva

A 45-element vector giving the daily gross value added of each economic sector in the model, in million dollars.

doi:10.1126/science.abc0035 and OECD; see processing details in 'data-raw/country_data.R


Country names and ISO codes for DAEDALUS

Description

Names and character codes for countries provided with the package. Note that country names are commonly used names and may not be official names.

  • country_names: Country names;

  • country_codes_iso3c: ISO 3166 alpha 3 (3 character) codes;

  • country_codes_iso2c: ISO 3166 alpha 2 (2 character) codes;

Usage

country_names

country_codes_iso3c

country_codes_iso2c

Format

Character vectors of recognised country names, and 3-character or 2-character codes.

An object of class character of length 67.

An object of class character of length 67.

Country codes are taken from the ISO 3166 specification and generated from country names using countrycode::countrycode().

Examples

country_names

country_codes_iso3c

country_codes_iso2c

Economic sector names

Description

Names or descriptions of openness of economic sectors modelled in daedalus, to which closures apply.

Usage

econ_sector_names

Format

econ_sector_names

A character vector of length N_ECON_SECTORS (45).

Multiple sources; to be updated shortly. See processing details in 'data-raw/closure_data.R

Examples

econ_sector_names

Economic sector contacts data for DAEDALUS

Description

Data on the per-capita social contacts within and between each economic sector of the DAEDALUS model.

Usage

economic_contacts

Format

economic_contacts

A list with two elements:

contacts_workplace

A numeric vector with N_ECON_SECTORS (45) elements, giving the per-capita contacts between workers within the same economic sector.

contacts_between_sectors

A square matrix with values set to 10610^{-6}, and with its diagonal set to zero, for the number of contacts between workers across economic sectors.

Adapted from doi:10.1016/j.epidem.2024.100778; see processing details in 'data-raw/economic_contacts.R


Infection characteristics for model epidemics

Description

Infection parameters used in DAEDALUS to simulate epidemics of interest.

epidemic_names provides the tags by which epidemics are known for users' convenience.

Usage

infection_data

infection_parameter_names

epidemic_names

Format

infection_data

A list with 7 elements, each corresponding to an epidemic (see Details), and providing 10 infection parameters:

  • r0: A single numeric value for the basic reproduction value of the infection R0R_0.

  • sigma: A single numeric value > 0.0 for the rate of transition from the exposed compartment to one of two infectious compartments.

  • p_sigma: A single numeric value in the range (0.0,1.0)(0.0, 1.0) for the proportion of infectious individuals who are also symptomatic. Asymptomatic individuals can have a different contribution to the force of infection from symptomatic individuals.

  • epsilon: A single numeric value for the relative contribution of asymptomatic infectious individuals to the force of infection (compared to symptomatic individuals).

  • gamma_Is: A single numeric value for the recovery rate of infectious individuals who are not hospitalised.

  • gamma_Ia: A single numeric value for the recovery rate from asymptomatic infection.

  • gamma_H_recovery: A single numeric value for the rate of transition from hospital admission to recovery.

  • gamma_H_death: A single numeric value for the rate of transition from hospital admission to death.

  • hfr: A numeric vector of length 4 for the age-specific hospital fatality ratio.

  • eta: A numeric vector of length N_AGE_GROUPS (4) for the age-specific hospitalisation rate for individuals who are infectious and symptomatic.

  • rho: A single numeric value for the rate at which infection-derived immunity wanes, returning individuals in the 'recovered' compartment to the 'susceptible' compartment.

infection_parameter_names

A character vector with 10 names for the infection parameters in infection_data. Mainly for internal use.

epidemic_names

A character vector with 7 elements.

Details

Epidemics for which data are available are (pathogen in parentheses):

  • SARS 2004 (SARS-CoV-1)

  • Influenza 2009 (influenza A H1N1)

  • Influenza 1957 (influenza A H2N2)

  • Influenza 1918 (influenza A H1N1)

  • Covid-19 wild type (SARS-Cov-2 wild type)

  • Covid-19 Omicron (SARS-CoV-2 omicron)

  • Covid-19 Delta (SARS-CoV-2 delta).

See processing details in 'data-raw/infection_data.R

Examples

# check available epidemics
epidemic_names

Life expectancies and values

Description

Data on country- and age-group-specific life expectancy, and values in dollars (scaled by purchasing power parity) of a statistical life lost in each of the four DAEDALUS age groups, accounting for life expectancy.

Usage

life_value

country_gni

life_expectancy

Format

life_value

A list with 67 elements, each corresponding to a country or territory, and giving the age-group-specific value of a statistical life lost. Each list element is a numeric vector of four values giving the value per age group, in the following order: 0-4, 5-19, 20-65, 65+.

country_gni

A list with 67 elements, each corresponding to a country or territory, and giving the GNI (gross national income) in international dollars.

country_gni

A list with 67 elements, each corresponding to a country or territory, and giving the life expectancy in years.

Multiple sources; see processing details in 'data-raw/life_value.R.

Multiple sources; see processing details in 'data-raw/life_value.R.

Multiple sources; see processing details in 'data-raw/life_value.R.


Vaccine investment scenario parameters

Description

Vaccination parameters for four main pre-pandemic scenarios of pre-pandemic investments in vaccine development and delivery.

vaccination_scenario_names provides the names by which the advance vaccine investment scenarios are known.

Usage

vaccination_scenario_data

vaccination_scenario_names

vaccination_parameter_names

Format

vaccination_scenario_data

A list with 4 elements, each corresponding to an advance vaccine investment strategy. Each element is a list of three values (see Details).

  • vax_start_time: A single number for the vaccination start time in days.

  • nu: A single number for the daily vaccination rate as a percentage of the population vaccinated.

  • vax_uptake_limit: A single number for the percentage of the population that is willing to be vaccinated.

vaccination_scenario_names

A character vector of four elements giving the identifier for each scenario.

vaccination_parameter_names

A character vector of three elements giving the identifier for vaccination parameters.

An object of class character of length 4.

An object of class character of length 5.

Details

Each scenario has three parameters; parameters do not differ across age or other groups.

  • Vaccination start time: The time in days at which vaccination begins.

  • Vaccination rate: The rate, as a percentage of the population vaccinated per day.

  • Vaccination uptake limit: The percentage of the population that is willing to accept vaccination.

See processing details in 'data-raw/vaccination_data.R

Examples

# check vaccination scenarios
vaccination_scenario_names

vaccination_scenario_data